/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


package com.sisme.entitats;

import java.util.HashSet;
import java.util.Set;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.Id;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;

/*************************************************************************************************
 * Classe: Escala
 * 
 * Classe entitat que defineix una escala per catalogar moviments sísmics i la seva persistencia
 *************************************************************************************************/

@Entity
@Table(name = "escales")
public class Escala implements java.io.Serializable {

	/*-----------------------------------------------------------------------------------------------
	 * Atributs
	 *-----------------------------------------------------------------------------------------------*/

	/**
	 * 
	 */
	private static final long serialVersionUID = -2083415017902880241L;
	private Integer idEscala;
	private String nom;
	private Set<Magnitud> magnituds = new HashSet<Magnitud>(0);

	/*-----------------------------------------------------------------------------------------------
	 * Metodes
	 *-----------------------------------------------------------------------------------------------*/
	public Escala() {}

	public Escala(Integer idEscala, String nom) {
		this.idEscala = idEscala;
		this.nom = nom;
	}

	public Escala(Integer idEscala, String nom, Set<Magnitud> magnituds) {
		this.idEscala = idEscala;
		this.nom = nom;
		this.magnituds = magnituds;
	}


	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(name = "idescala", unique = true, nullable = false)
	public Integer getIdEscala() {
		return this.idEscala;
	}

	public void setIdEscala(Integer idEscala) {
		this.idEscala = idEscala;
	}

	@Column(name = "nom", nullable = false, length = 40)
	public String getNom() {
		return this.nom;
	}

	public void setNom(String nom) {
		this.nom = nom;
	}


	@OneToMany(cascade = CascadeType.ALL, fetch = FetchType.EAGER, mappedBy = "escala")
	public Set<Magnitud> getMagnituds() {
		return this.magnituds;
	}

	public void setMagnituds(Set<Magnitud> magnituds) {
		this.magnituds = magnituds;
	}
	
	
	

}