/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/*************************************************************************************************
 * Classe: Mostra
 * 
 * Classe entitat que defineix una mostra corresponent a un moviment sísmic i la seva persistencia
 *************************************************************************************************/
package com.sisme.entitats;

import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.Table;


@Entity
@Table(name="mostres")
public class Mostra implements Serializable {

	
/**
 * 
 */
	private static final long serialVersionUID = 1L;
/*-------------------------------------------------------------------------------------------
 * Atributs
 *-------------------------------------------------------------------------------------------*/
	private long idMostra;
	private Moviment moviment;
	private long tStamp;
	private float coordX;
	private float coordY;
	private float coordZ;
	
	
/*-------------------------------------------------------------------------------------------
 * Metodes constructors
 *-------------------------------------------------------------------------------------------*/
	public Mostra() {}

	public Mostra(long idMostra, Moviment moviment, long tStamp, float coordX, float coordY, 
			float coordZ) {
		this.idMostra = idMostra;
		this.moviment = moviment;
		this.tStamp = tStamp;
		this.coordX = coordX;
		this.coordY = coordY;
		this.coordZ = coordZ;
	}

	
	public Mostra(Moviment moviment, long tStamp, float coordX, float coordY, float coordZ) {
		this.moviment = moviment;
		this.tStamp = tStamp;
		this.coordX = coordX;
		this.coordY = coordY;
		this.coordZ = coordZ;
	}
	
/*-------------------------------------------------------------------------------------------
 * Metodes
 *-------------------------------------------------------------------------------------------*/

	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(name = "idmostra", unique = true, nullable = false)
	public long getIdMostra() {
		return this.idMostra;
	}

	public void setIdMostra(long idMostra) {
		this.idMostra = idMostra;
	}
	
	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name = "idmoviment", nullable = false)
	public Moviment getMoviment() {
		return this.moviment;
	}

	public void setMoviment(Moviment moviment) {
		this.moviment = moviment;
	}

	@Column(name = "tstamp")
	public long getTstamp() {
		return this.tStamp;
	}

	public void setTstamp(long tStamp) {
		this.tStamp = tStamp;
	}

	@Column(name = "coordx", precision = 12, scale = 0)
	public float getCoordX() {
		return this.coordX;
	}

	public void setCoordX(float coordX) {
		this.coordX = coordX;
	}

	@Column(name = "coordy", precision = 12, scale = 0)
	public float getCoordY() {
		return this.coordY;
	}

	public void setCoordY(float coordY) {
		this.coordY = coordY;
	}

	@Column(name = "coordz", precision = 12, scale = 0)
	public float getCoordZ() {
		return this.coordZ;
	}

	public void setCoordZ(float coordZ) {
		this.coordZ = coordZ;
	}


}