/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/******************************************************************************************
 * Classe: Moviment
 * 
 * Classe entitat que defineix un moviment de deteccio de sisme i la seva persistencia
 ******************************************************************************************/
package com.sisme.entitats;

import java.io.Serializable;
import java.util.Date;
import java.util.HashSet;
import java.util.Set;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;


@Entity
@Table(name="moviments")
public class Moviment implements Serializable {

	
/*************************************************************************************************
 * Classe: Moviment
 * 
 * Classe entitat que defineix una mostra corresponent a un moviment sísmic i la seva persistencia
 *************************************************************************************************/
	private static final long serialVersionUID = 1654599400523109014L;
	/*-------------------------------------------------------------------------------------------
 * Atributs
 *-------------------------------------------------------------------------------------------*/
	private long idMoviment;
	private Date dataHora;
	private float latitud;
	private float longitud;
	private boolean ocult;
	private boolean anulat;
	private Magnitud magnitud;
	private Set<Mostra> mostres = new HashSet<Mostra>(0);
	private float intensitat;
	
	
/*-------------------------------------------------------------------------------------------
 * Metodes constructors
 *-------------------------------------------------------------------------------------------*/
	public Moviment() {
		this.magnitud = new Magnitud();
	}

	public Moviment(long idMoviment, Date dataHora, float latitud, float longitud, float intensitat, 
			boolean ocult, boolean anulat, Magnitud magnitud) {
		this.idMoviment = idMoviment;
		this.dataHora = dataHora;
		this.latitud = latitud;
		this.longitud = longitud;
		this.ocult = ocult;
		this.anulat = anulat;
		this.magnitud = magnitud;
	}
	

	public Moviment(long idMoviment, Date dataHora, float latitud, float longitud, float intensitat, 
			boolean ocult, boolean anulat, Magnitud magnitud, Set<Mostra> mostres) {
		this.idMoviment = idMoviment;
		this.dataHora = dataHora;
		this.latitud = latitud;
		this.longitud = longitud;
		this.ocult = ocult;
		this.anulat = anulat;
		this.magnitud = magnitud;
		this.mostres = mostres;
	}
	
	
/*-------------------------------------------------------------------------------------------
 * Metodes
 *-------------------------------------------------------------------------------------------*/

	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(name = "idmoviment", unique = true, nullable = false)
	public long getIdMoviment() {
		return this.idMoviment;
	}

	public void setIdMoviment(long idMoviment) {
		this.idMoviment = idMoviment;
	}

	@Temporal(TemporalType.TIMESTAMP)
	@Column(name = "datahora", nullable = false, length = 10)
	public Date getDataHora() {
		return this.dataHora;
	}

	public void setDataHora(Date dataHora) {
		this.dataHora = dataHora;
	}

	@Column(name = "latitud", nullable = false, precision = 12, scale = 0)
	public float getLatitud() {
		return this.latitud;
	}

	public void setLatitud(float latitud) {
		this.latitud = latitud;
	}

	@Column(name = "longitud", nullable = false, precision = 12, scale = 0)
	public float getLongitud() {
		return this.longitud;
	}

	public void setLongitud(float longitud) {
		this.longitud = longitud;
	}

	@Column(name = "ocult")
	public boolean getOcult() {
		return this.ocult;
	}

	public void setOcult(boolean ocult) {
		this.ocult = ocult;
	}
	
	@Column(name = "anulat")
	public boolean getAnulat() {
		return this.anulat;
	}

	public void setAnulat(boolean anulat) {
		this.anulat = anulat;
	}
	
	/**
	 * Getter que retorna la magnitud del sisme
	 * @return marca
	 */
	@ManyToOne(fetch = FetchType.EAGER)
	@JoinColumn(name = "idmagnitud", nullable = false)
	public Magnitud getMagnitud() {
		return this.magnitud;
	}

	/**
	 * Setter que assigna la magnitud del sisme
	 * @param mgtd
	 */
	public void setMagnitud(Magnitud magnitud) {
		this.magnitud = magnitud;
	}
	
	@OneToMany(cascade = CascadeType.ALL, fetch = FetchType.LAZY, mappedBy = "moviment")
	public Set<Mostra> getMostres() {
		return this.mostres;
	}

	public void setMostres(Set<Mostra> mostres) {
		this.mostres = mostres;
	}
	
	@Column(name = "intensitat", nullable = false, precision = 12, scale = 0)
	public float getIntensitat() {
		return this.intensitat;
	}

	public void setIntensitat(float intensitat) {
		this.intensitat = intensitat;
	}
	

}