/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/******************************************************************************************
 * Classe: MagnitudServiceBean
 * 
 * Classe que implementa els metodes del bean de magnituds
 ******************************************************************************************/
package com.sisme.serveis;

import javax.ejb.Stateless;
import javax.ejb.Remote;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import com.sisme.entitats.Magnitud;
import com.sisme.generic.SismeException;
import com.sisme.interficies.MagnitudService;


@Stateless
@Remote(MagnitudService.class)
public class MagnitudServiceBean implements MagnitudService {

    @PersistenceContext(unitName = "SismeServerEJBPU")
    private EntityManager entityManager;
	
    /*-------------------------------------------------------------------------------------------
     * Metodes constructors
     *-------------------------------------------------------------------------------------------*/
    public MagnitudServiceBean() {}


	/*-------------------------------------------------------------------------------------------
	 * Metodes
	 *-------------------------------------------------------------------------------------------*/
    
    // Desa la nova magnitud a la base de dades i la retorna amb el idmagnitud assignat automaticament
	public Magnitud desar(Magnitud magnitud) throws SismeException {
		try {
			Magnitud m = entityManager.merge(magnitud);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MagnitudService.desar]: " + e.getMessage());
		}
	}
	
	// Elimina la magnitud a la base de dades
	public void eliminar(Magnitud magnitud) throws SismeException {
		try {
			magnitud = entityManager.getReference(Magnitud.class, magnitud.getIdMagnitud());
			entityManager.remove(magnitud);
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MagnitudService.eliminar]: " + e.getMessage());
		}
	}
	
	// Actualitza la Magnitud a la base de dades
	public Magnitud actualitzar(Magnitud magnitud) throws SismeException {
		try {
			Magnitud m = entityManager.merge(magnitud);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MagnitudService.actualitzar]: " + e.getMessage());
		}
	}


	// Recerca una magnitud a la base de dades a partir del IdMagnitud
	public Magnitud cercaIdMagnitud(long idMagnitud) throws SismeException {
		try {
			Magnitud m = entityManager.find(Magnitud.class, idMagnitud);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MagnitudService.cercaId]: " + e.getMessage());
		}
	}
	
	
	// Recerca una magnitud a la base de dades a partir de la intensitat 
	public Magnitud cercaMagnitudPerIntensitat(float intensitat) throws SismeException {
		try {

			Query query = null;
			String queryString = "select m from Magnitud m "
					+ "where m.magnitudMinima <= :intensitat and m.magnitudMaxima >= :intensitat "
					+ "order by m.idMagnitud";

			query = entityManager.createQuery(queryString);
			query.setParameter("intensitat", intensitat);
			
			Magnitud rmg = new Magnitud();
			if(query.getResultList().size()>0) {
				rmg = (Magnitud)query.getResultList().get(0); 
			}else{
				rmg = null;
			}
			return rmg;
			
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MagnitudService.cercaMagnitudPerIntensitat]: " + e.getMessage());
		}
	}

	// Retorna una llista de totes les magnituds per IdMagnitud
	@SuppressWarnings("unchecked")
	public List<Magnitud> llistaIdMagnituds(String ascDesc) throws SismeException {
		try {
			final String qstr = "select m from Magnitud m order by m.idmagnitud "+(ascDesc.compareTo("")!=0?"desc":"");
			Query q = entityManager.createQuery(qstr);
			List<Magnitud> llm = q.getResultList();
			return llm;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MagnitudService.llistaIdMagnituds]: " + e.getMessage());
		}
	}
    

}
