/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/******************************************************************************************
 * Classe: MostraServiceBean
 * 
 * Classe que implementa els metodes del bean de mostres de Mostras sismics
 ******************************************************************************************/
package com.sisme.serveis;

import javax.ejb.Stateless;
import javax.ejb.Remote;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import com.sisme.entitats.Mostra;
import com.sisme.generic.SismeException;
import com.sisme.interficies.MostraService;


@Stateless
@Remote(MostraService.class)
public class MostraServiceBean implements MostraService {

    @PersistenceContext(unitName = "SismeServerEJBPU")
    private EntityManager entityManager;
	
    /*-------------------------------------------------------------------------------------------
     * Metodes constructors
     *-------------------------------------------------------------------------------------------*/
    public MostraServiceBean() {}


	/*-------------------------------------------------------------------------------------------
	 * Metodes
	 *-------------------------------------------------------------------------------------------*/
    
    // Desa el nou Mostra a la base de dades i el retorna amb el id assignat automaticament
	public Mostra desar(Mostra Mostra) throws SismeException {
		try {
			Mostra m = entityManager.merge(Mostra);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MostraService.desar]: " + e.getMessage());
		}
	}
	
	// Elimina el Mostra a la base de dades
	public void eliminar(Mostra Mostra) throws SismeException {
		try {
			Mostra = entityManager.getReference(Mostra.class, Mostra.getIdMostra());
			entityManager.remove(Mostra);
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MostraService.eliminar]: " + e.getMessage());
		}
	}
	
	// Actualitza el Mostra a la base de dades
	public Mostra actualitzar(Mostra Mostra) throws SismeException {
		try {
			Mostra m = entityManager.merge(Mostra);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MostraService.actualitzar]: " + e.getMessage());
		}
	}


	// Recerca un Mostra a la base de dades a partir del IdMostra
	public Mostra cercaIdMostra(long idMostra) throws SismeException {
		try {
			Mostra m = entityManager.find(Mostra.class, idMostra);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MostraService.cercaId]: " + e.getMessage());
		}
	}
	

	// Retorna una llista de totes les Mostres d'un moviment
	@SuppressWarnings("unchecked")
	public List<Mostra> llistaMostresMoviment(long idMoviment, String ascDesc) throws SismeException {
		try {
			final String qstr = "select m from Mostra m "
					+ "where m.moviment.idMoviment =: idMoviment "
					+ "order  by m.idMostra "+(ascDesc.compareTo("")!=0?"desc":"");
			Query q = entityManager.createQuery(qstr);
			List<Mostra> llm = q.getResultList();
			return llm;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MostraService.llistaMostresMoviment]: " + e.getMessage());
		}
	}
    

}
