/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/******************************************************************************************
 * Classe: MovimentServiceBean
 * 
 * Classe que implementa els metodes del bean de moviments
 ******************************************************************************************/
package com.sisme.serveis;

import javax.ejb.Stateless;
import javax.ejb.Remote;
import java.util.Date;
import java.util.List;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import com.sisme.entitats.Moviment;
import com.sisme.generic.SismeException;
import com.sisme.interficies.MovimentService;


@Stateless
@Remote(MovimentService.class)
public class MovimentServiceBean implements MovimentService {

    @PersistenceContext(unitName = "SismeServerEJBPU")
    private EntityManager entityManager;
	
    /*-------------------------------------------------------------------------------------------
     * Metodes constructors
     *-------------------------------------------------------------------------------------------*/
    public MovimentServiceBean() {}


	/*-------------------------------------------------------------------------------------------
	 * Metodes
	 *-------------------------------------------------------------------------------------------*/
    
    // Desa el nou moviment a la base de dades i el retorna amb el id assignat automaticament
	public Moviment desar(Moviment moviment) throws SismeException {
		try {
			Moviment m = entityManager.merge(moviment);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MovimentService.desar]: " + e.getMessage());
		}
	}
	
	// Elimina el moviment a la base de dades
	public void eliminar(Moviment moviment) throws SismeException {
		try {
			moviment = entityManager.getReference(Moviment.class, moviment.getIdMoviment());
			entityManager.remove(moviment);
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MovimentService.eliminar]: " + e.getMessage());
		}
	}
	
	// Actualitza el moviment a la base de dades
	public Moviment actualitzar(Moviment moviment) throws SismeException {
		try {
			Moviment m = entityManager.merge(moviment);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MovimentService.actualitzar]: " + e.getMessage());
		}
	}


	// Recerca un moviment a la base de dades a partir del IdMoviment
	public Moviment cercaIdMoviment(long idMoviment) throws SismeException {
		try {
			Moviment m = entityManager.find(Moviment.class, idMoviment);
			return m;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MovimentService.cercaId]: " + e.getMessage());
		}
	}
	

	// Retorna una llista de tots els moviments per IdMoviment
	@SuppressWarnings("unchecked")
	public List<Moviment> llistaIdMoviments(String ascDesc) throws SismeException {
		try {
			final String qstr = "select m from Moviment m order by m.idMoviment "+(ascDesc.compareTo("")!=0?"desc":"");
			Query q = entityManager.createQuery(qstr);
			List<Moviment> llm = q.getResultList();
			return llm;
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MovimentService.llistaIdMoviments]: " + e.getMessage());
		}
	}
    

	// Retorna una llista de tots els moviments per IdMoviment segons els parametres de recerca
	@SuppressWarnings("unchecked")
	public List<Moviment> recercaMoviments(final String ascDesc, Date dataInici, Date dataFinal, float intensitatInicial, float intensitatFinal) throws SismeException {
		try {
			
			Query query = null;
			String queryString = "select m from Moviment m where m.anulat=false ";

			if(dataInici!=null) {
				queryString += "and m.dataHora >= :dataInici "; 
			}
			if(dataFinal!=null) {
				queryString += "and m.dataHora<= :dataFinal "; 
			}
			if(intensitatInicial!=0.0F) {
				queryString += "and m.intensitat >= :intensitatInicial "; 
			}
			if(intensitatFinal!=0.0F) {
				queryString += "and m.intensitat<= :intensitatFinal "; 
			}
			queryString +="order by m.idMoviment "+(ascDesc.compareTo("")!=0?"desc":"");
			
			query = entityManager.createQuery(queryString);
			if(dataInici!=null) query.setParameter("dataInici", dataInici);
			if(dataFinal!=null)query.setParameter("dataFinal", dataFinal);
			if(intensitatInicial!=0.0F) query.setParameter("intensitatInicial", intensitatInicial);
			if(intensitatFinal!=0.0F)query.setParameter("intensitatFinal", intensitatFinal);
			return query.getResultList();
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[MovimentService.recerca]: " + e.getMessage());
		}
	}
	
}
