/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/******************************************************************************************
 * Classe: SismeRcvDataServiceBean
 * 
 * Classe que implementa els metodes del bean del Web Service de recepcio de moviments
 ******************************************************************************************/
package com.sisme.ws.serveis;

import javax.ejb.Stateless;
import javax.jws.WebMethod;
import javax.jws.WebService;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import com.sisme.entitats.Magnitud;
import com.sisme.entitats.Mostra;
import com.sisme.entitats.Moviment;
import com.sisme.generic.SismeException;
import com.sisme.ws.interficies.SismeRcvDataService;


@Stateless
@WebService(serviceName="SismeRcvDataService")
public class SismeRcvDataServiceBean implements SismeRcvDataService {

	@PersistenceContext(unitName="SismeServerEJBPU")
	private EntityManager entityManager;    
	

	public SismeRcvDataServiceBean(){}

 

	/*-------------------------------------------------------------------------------------------
	 * Metodes
	 *-------------------------------------------------------------------------------------------*/
	
	// Adquisicio de les dades del moviment rebudes pel WebService
	@WebMethod(operationName="rcvData")
	public long rcvData (float latitud, float longitud, float intensitat, long dataHora, 
			float[] mostresX, float[] mostresY, float[] mostresZ, long[] mostresT) {
		
		long valret = 0;
		
		// Si els valors latitud, longitud, intensitat son 0: no es processa la informacio ni s'emet
		// error ja que es considera un moviment de test de comunicacio del client amb el servidor.
		if(latitud!=0.0 || longitud!=0.0 || intensitat!=0.0)
		{
			
			// Crea el moviment
			Moviment m = new Moviment();
			m.setIdMoviment(0);
			m.setLatitud(latitud);
			m.setLongitud(longitud);
			m.setIntensitat(intensitat);
			m.setDataHora(new java.util.Date(dataHora));
			m.setOcult(false);
			m.setAnulat(false);
			
			// Cerca la magnitud a partir de la intensitat rebuda
			try {
				m.setMagnitud(this.cercaMagnitudPerIntensitat(intensitat));
			} catch (SismeException e) {
				return 0;
			}
		
			// Desa el nou moviment a la base de dades i el retorna amb el id assignat automaticament
			try {
				m = entityManager.merge(m);
			
				for(int f=0; f<mostresX.length; f++)
				{
					Mostra mostra = new Mostra();
					mostra.setMoviment(m);
					mostra.setCoordX(mostresX[f]);
					mostra.setCoordY(mostresY[f]);
					mostra.setCoordZ(mostresZ[f]);
					mostra.setTstamp(mostresT[f]);
			
					m.getMostres().add(mostra);
					Mostra mstr = entityManager.merge(mostra);
				}
			} catch (Exception e) {
				return 0;
			}
		
		}else{
			System.out.println("Moviment de test detectat...");
		}
		return (valret);
	}
	
	
	
	// Recerca una magnitud a la base de dades a partir de la intensitat 
	private Magnitud cercaMagnitudPerIntensitat(float intensitat) throws SismeException {
		try {

			Query query = null;
			String queryString = "select m from Magnitud m "
				+ "where m.magnitudMinima <= :intensitat and m.magnitudMaxima >= :intensitat "
				+ "order by m.idMagnitud";
			query = this.entityManager.createQuery(queryString);
			query.setParameter("intensitat", intensitat);
		
			Magnitud rmg = new Magnitud();
			if(query.getResultList().size()>0) {
				rmg = (Magnitud)query.getResultList().get(0); 
			}else{
				rmg = null;
			}
			return rmg;
			
		} catch (RuntimeException e) {
			throw new SismeException("ERROR->[WS-MagnitudService.cercaMagnitudPerIntensitat]: " + e.getMessage());
		}
	}
   
}
