/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


/**
 * ConsultaHistoricaBean.java
 * Bean per gestionar la pagina de consulta historica de moviments
 */

package com.sisme.webclient.managedbeans;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import com.sisme.entitats.Magnitud;
import com.sisme.entitats.Moviment;
import com.sisme.generic.SismeException;
import com.sisme.interficies.MagnitudService;
import com.sisme.interficies.MovimentService;

@ManagedBean
@SessionScoped
public class ConsultaHistoricaBean
{
	
	//Atributs
	private MovimentService ms = null;
	private Date dataInici = new Date();
    private Date dataFinal = new Date();
    private float intensitatInici = 0.0F;
    private float intensitatFinal = 99.0F;
    private String parmDatIni = null;
    private String parmDatFin = null;
    private float parmIntIni = 0.0F;
    private float parmIntFin = 0.0F;
    private String url = "";
	private List<Moviment> llm = new ArrayList<Moviment>();
	private boolean llmVisible = false;
	private boolean connexioActiva = false;
	private MagnitudService gs = null;
	private Magnitud mag = new Magnitud();

    /**
     * Constructor
     */
	public ConsultaHistoricaBean() throws SismeException {
		if(connexioActiva==false) {
			try {
				InitialContext ctx = new InitialContext();
				this.ms = (MovimentService) ctx.lookup("java:app/SismeServerEJB/MovimentServiceBean");
				this.gs = (MagnitudService) ctx.lookup("java:app/SismeServerEJB/MagnitudServiceBean");
				this.setMag(this.gs.cercaMagnitudPerIntensitat(9.8F));				
				System.out.println("ConsultaHistoricaBean connectat");
				connexioActiva=true;
			} catch (NamingException e) {
				e.printStackTrace();
			}
		}
			
	}
	
	
	/**
	 * Getters i setters
	 */
	@Temporal(TemporalType.DATE)
	public Date getDataInici() {
		return this.dataInici;
	}
	
	@Temporal(TemporalType.DATE)
	public void setDataInici(Date dataInici) {
		this.dataInici = dataInici;
	}
	
	@Temporal(TemporalType.DATE)
	public Date getDataFinal() {
		return this.dataFinal;
	}
	
	@Temporal(TemporalType.DATE)
	public void setDataFinal(Date dataFinal) {
		this.dataFinal = dataFinal;
	}
	
	public float getIntensitatInici() {
		return this.intensitatInici;
	}
	
	public void setIntensitatInici(float intensitatInici) {
		this.intensitatInici = intensitatInici;
	}
	
	public float getIntensitatFinal() {
		return this.intensitatFinal;
	}
	
	public void setIntensitatFinal(float intensitatFinal) {
		this.intensitatFinal = intensitatFinal;
	}

	public List<Moviment> getLlm() {
		return llm;
	}

	public void setLlm(List<Moviment> llm) {
		this.llm = llm;
	}

	public boolean isLlmVisible() {
		return llmVisible;
	}

	public void setLlmVisible(boolean llmVisible) {
		this.llmVisible = llmVisible;
	}

	public String getParmDatIni() {
		return parmDatIni;
	}

	public void setParmDatIni(String parmDatIni) {
		this.parmDatIni = parmDatIni;
	}

	public String getParmDatFin() {
		return parmDatFin;
	}

	public void setParmDatFin(String parmDatFin) {
		this.parmDatFin = parmDatFin;
	}

	public float getParmIntIni() {
		return parmIntIni;
	}

	public void setParmIntIni(float parmIntIni) {
		this.parmIntIni = parmIntIni;
	}

	public float getParmIntFin() {
		return parmIntFin;
	}

	public void setParmIntFin(float parmIntFin) {
		this.parmIntFin = parmIntFin;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public Magnitud getMag() {
		return mag;
	}

	public void setMag(Magnitud mag) {
		this.mag = mag;
	}
	
	// Fa la recerca dels moviments a partir dels valors dels parametres introduits
	public void recercar()
	{
		// Adaptar valors dels parametres per crida posterior al servlet SismeWebMapHistory
		this.setParmDatIni(String.valueOf(this.dataInici.getTime()));
		this.setParmDatFin(String.valueOf(this.dataFinal.getTime()));
		this.setParmIntIni(this.intensitatInici);
		this.setParmIntFin(this.intensitatFinal);
		this.url = "SismeWebMapHistory?parmDatIni="+this.parmDatIni+"&parmDatFin="+this.parmDatFin+
				"&parmIntIni="+String.valueOf(this.parmIntIni)+"&parmIntFin="+String.valueOf(this.parmIntFin);
		try {
			this.llm = this.ms.recercaMoviments("ascendent", this.dataInici, this.dataFinal, this.intensitatInici, this.intensitatFinal);
			if(this.llm.size()>0)
			{
				this.llmVisible=true;
			}else{
				this.llmVisible=false;
			}
		} catch (SismeException e) {
			this.llmVisible=false;
		}


	}

}
