/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Servlet que genera el mapa de (R)Google a partir dels parametres i el retorna en forma de codi HTML
 * S'actualiza de forma automatica i va enllaçada amb la pagina de consulta historica de moviments
 * El codi que retorna esta basat en codi de les pagina de demostracions de Google i esta subjecte a la
 * llicencia corresponent.
 * 
 */
package com.sisme.webclient.servlets;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import com.sisme.entitats.Moviment;
import com.sisme.generic.SismeException;
import com.sisme.interficies.MovimentService;

@WebServlet("/SismeWebMapHistory")
public class SismeWebMapHistory extends HttpServlet {
	private static final long serialVersionUID = 1L;
	
	// Assignacio de les coordenades de la situacio del sistema
	private static final float latitudSistema=41.385064F;
	private static final float longitudSistema=2.173404F;
	
	// Temps de refresc de la pagina en segons
	private static final int refrescPagina=30;
	
	// Parametres rebuts per fer la consulta a la base de dades i generar el mapa
	private Date parmDatIni = new Date();
	private Date parmDatFin = new Date();
	private String parmIntIni = "";
	private String parmIntFin = "";
    
	
	/**
     * Constructor
     */
    public SismeWebMapHistory() {
        super();
    }

	/**
	 * Servei actiu per a GET
	 */
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		if (request.getParameter("parmDatIni") != null) {
			this.parmDatIni.setTime(Long.parseLong(request.getParameter("parmDatIni")));
		}
        if (request.getParameter("parmDatFin") != null) {
        	this.parmDatFin.setTime(Long.parseLong(request.getParameter("parmDatFin")));
        }
			
        if (request.getParameter("parmIntIni") != null) {
        	parmIntIni=request.getParameter("parmIntIni");}
        if (request.getParameter("parmIntFin") != null) {
        	parmIntFin=request.getParameter("parmIntFin");}

		
		PrintWriter out = response.getWriter();
        try {
        	InitialContext ctx = new InitialContext();
        	MovimentService ms = (MovimentService) ctx.lookup("java:app/SismeServerEJB/MovimentServiceBean");

    		// Generem una cadena amb la informacio necessaria per efectuar la geolocalitzacio dels moviments
    		String ma="";
    		List<Moviment> llm = new ArrayList<Moviment>();
    		llm=ms.recercaMoviments("ascendent", this.parmDatIni, this.parmDatFin, Float.valueOf(this.parmIntIni), Float.valueOf(this.parmIntFin));
    		for(int n=0;n<llm.size();n++) {
    			ma=ma+"['"+llm.get(n).getIntensitat()+": "+llm.get(n).getMagnitud().getDescripcio()+"',"+llm.get(n).getLatitud()+","+llm.get(n).getLongitud()+"]";
    			if(n<llm.size()-1) {ma=ma+",";}
    		}
    		
    		
    		/**
    		 * Genera una resposta HTML amb la informacio del moviment en el mapa
    		 */
    		out.println("<!DOCTYPE html>");
    		out.println("<html>");
    		out.println("<head>");
    		out.println("<meta charset=\"UTF-8\">");
    		out.println("<title>Moviments sismics TFM Jaume Lopez</title>");
    		out.println("</head>");
    		out.println("<style>html, body, #map {height: 100%;margin: 0px;padding: 0px}</style>");
    		out.println("<script type=\"text/javascript\" src=\"http://maps.googleapis.com/maps/api/js?sensor=true\"></script>");
    		out.println("<script>");
    		out.println("function initialize() {");
			out.println("var locations = ["+ma+"];");
			out.println("var map = new google.maps.Map(document.getElementById('map'), {");
			out.println("zoom: 11,");
			out.println("center: new google.maps.LatLng("+latitudSistema+","+longitudSistema+"),");
			out.println("mapTypeId: google.maps.MapTypeId.HYBRID");
			out.println("});");
			out.println("var infowindow = new google.maps.InfoWindow();");
			out.println("var marker, i;");
			out.println("for (i = 0; i < locations.length; i++) {");
			out.println("marker = new google.maps.Marker({");
			out.println("position: new google.maps.LatLng(locations[i][1], locations[i][2]),");
			out.println("map: map");
			out.println("});");
			out.println("google.maps.event.addListener(marker, 'click', (function(marker, i) {");
			out.println("return function() {");
			out.println("infowindow.setContent('Intensitat: '+locations[i][0]+'\\nLatitud: '+locations[i][1]+'\\nLongitud: '+locations[i][2]);");
			out.println("infowindow.open(map, marker);");
			out.println("}");
			out.println("})(marker, i));");
			out.println("}");
    		                                                         
    		// Detecta si la geolocalitzacio esta suportada
			out.println("if (navigator.geolocation) {");
			out.println("navigator.geolocation.getCurrentPosition(function(position) {");
			out.println("var latitude = position.coords.latitude;");
			out.println("var longitude = position.coords.longitude;");
			out.println("var geolocpoint = new google.maps.LatLng(latitude, longitude);");
			out.println("var mapOptions = {");
			out.println("zoom: 11,");
			out.println("center: geolocpoint,");
			out.println("mapTypeId: google.maps.MapTypeId.HYBRID");
			out.println("}");
			
            // Insereix els marcadors
			out.println("var geolocation = new google.maps.Marker({");
			out.println("position: geolocpoint,");
			out.println("map: map,");
			out.println("title: 'Your geolocation',");
			out.println("icon: 'http://labs.google.com/ridefinder/images/mm_20_green.png'");
			out.println("});");
			out.println("});");
			out.println("}");
			out.println("}");
			out.println("google.maps.event.addDomListener(window, 'load', initialize);");
			out.println("</script>");
			out.println("<body>");
			out.println("<div id=\"map\"></div>");
			out.println("</body>");
			out.println("</html>");    		
    		
					
		} catch (SismeException e) {
			e.printStackTrace();
		} catch (NamingException e) {
			e.printStackTrace();
		} finally {
            out.close();
        }
	}

	/**
	 * Servei per a POST
	 */
	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {}

}
