/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*---------------------------------------------------------------------------------------- 
 * Classe Accelerometre: defineix un sensor d'acceleracio
 * 
 *----------------------------------------------------------------------------------------*/
function Accelerometre() {

	// Atributs
	this.coordX = 0.0;
	this.coordY = 0.0;
	this.coordZ = 0.0;
	this.tStamp = 0;
	this.estat = ESTAT_INDETERMINAT;

	
	// Metodes
	   
	// Getter
	this.getCoordX = function() {
		return this.coordX;
	};
	
	// Getter
	this.getCoordY = function() {
		return this.coordY;
	};
	
	// Getter
	this.getCoordZ = function() {
		return this.coordZ;
	};
	
	// Getter
	this.getEstat = function() {
		return this.estat;
	};

	// Getter increment de temps
	this.getTStamp = function() {
		return this.tStamp;
	};
	
	// Setter
	this.setCoordX = function(x) {
		this.coordX = x;
	};
	
	// Setter
	this.setCoordY = function(y) {
		this.coordY = y;
	};
	
	// Setter
	this.setCoordZ = function(z) {
		this.coordZ = z;
	};
	
	// Setter
	this.setEstat = function(estat) {
		this.estat = estat;
	};

	// Setter increment de temps
	this.setTStamp = function(ts) {
		this.tStamp = ts;
	};

}


/*---------------------------------------------------------------------------------------- 
 * Classe LlistaMostres: Gestiona una llista de mostres de l'accelerometre
 *----------------------------------------------------------------------------------------*/
function LlistaMostres() {
	// Atributs
	var llsamples = new Array();

	
	// Metodes:
	
	// Afegir mostra a la llista
	this.afegirMostra = function(sample) {
    	llsamples.push(sample);
	};
	
	// Eliminar mostra de la llista
	this.eliminarMostra = function(index) {
		llsamples.splice(index, 1);
	};
	
	// Obtenir el nombre d'elements de la llista
	this.obtenirNombreElements = function() {
		return llsamples.length;
	};
	
	// Afegir mostra al principi de la llista
	this.afegirMostraInici = function(sample) {
		llsamples.unshift(mostra);
	};
	
	// Modifica un element de la llista
	this.modificarMostra = function(index, sample) {
		llsamples[index] = sample;
	};
	
	// Recupera un element de la llista
	this.obtenirMostra = function(index) {
		return llsamples[index];
	};
	
	
	// Inicialitza la llista
	this.esborraLlista = function() {
		llsamples.length = 0;
	};
     	
 }




/*---------------------------------------------------------------------------------------- 
 * Classe GestorAccelerometre: gestiona l'accelerometre
 * 
 * 
 *----------------------------------------------------------------------------------------*/
function GestorAccelerometre() {

	// Atributs
	this.accelerometre = new Accelerometre();
	this.magnitud = 0.0;			
	
	this.prevX = 0.0;	// Valors previs intermitjos pel calcul dels increments
	this.prevY = 0.0;
	this.prevZ = 0.0;
	this.prevT = 0;
	this.ultimTimestampCapturat = 0;
	
	this.idEventAccelerometre = 0;			//	Id tasca accelerometre activat per test
	
	var llmostres = new LlistaMostres();			// Array de mostres
	var llmostresTest = new LlistaMostres();		// Array de mostres de Test
    llmostresTest.afegirMostra(this.accelerometre);	// Mostra de test
	
	this.idEventMostreig = 0;				// Id tasca mostreig
	this.idEventProcesMostreig = 0;			// Id tasca processar mostreig
	
	// Carrega l'escala de Mercalli Modificada per obtenir el nivell del moviment (Per aplicar en el futur).
	llmercalli = new Array();
	this.escalaMercalli = new Mercalli();
	this.escalaMercalli.carregaTaulaMercalli();
	
	// Metodes
	
	/**
	 * Dibuixa la base de les grafiques en pantalla
	 */
	this.dibuixaBaseGrafica = function() {

		var _innerHtml = '<canvas id=\"graficaX\" width=\"'+GRAFICA_AMPLE+'\" height=\"'+GRAFICA_ALT+'\">';
		document.getElementById("g1").innerHTML = _innerHtml;
		var _innerHtml = '<canvas id=\"graficaY\" width=\"'+GRAFICA_AMPLE+'\" height=\"'+GRAFICA_ALT+'\">';
		document.getElementById("g2").innerHTML = _innerHtml;
		var _innerHtml = '<canvas id=\"graficaZ\" width=\"'+GRAFICA_AMPLE+'\" height=\"'+GRAFICA_ALT+'\">';
		document.getElementById("g3").innerHTML = _innerHtml;
		
		// Atributs per a la base de les grafiques del mostreig
		window.graficaX = document.getElementById("graficaX");
		window.ctxgX = window.graficaX.getContext("2d");
		window.graficaY = document.getElementById("graficaY");
		window.ctxgY = window.graficaY.getContext("2d");
		window.graficaZ = document.getElementById("graficaZ");
		window.ctxgZ = window.graficaZ.getContext("2d");
		
		// Prepara el fons per dibuixar la grafica
		window.ctxgX.fillStyle = "#FFFFFF";
		window.ctxgX.fillRect(0,0,GRAFICA_AMPLE,GRAFICA_ALT);
		window.ctxgY.fillStyle = "#FFFFFF";
		window.ctxgY.fillRect(0,0,GRAFICA_AMPLE,GRAFICA_ALT);
		window.ctxgZ.fillStyle = "#FFFFFF";
		window.ctxgZ.fillRect(0,0,GRAFICA_AMPLE,GRAFICA_ALT);

		window.ctxgX.font="12px Arial";
		window.ctxgX.fillStyle ="black";
		window.ctxgX.fillText("EST/OEST", 4, 14);
		window.ctxgY.font="12px Arial";
		window.ctxgY.fillStyle ="black";
		window.ctxgY.fillText("NORD/SUD", 4, 14);		
		window.ctxgZ.font="12px Arial";
		window.ctxgZ.fillStyle ="black";
		window.ctxgZ.fillText("VERTICAL", 4, 14);
		window.ctxgX.stroke();
		window.ctxgY.stroke();
		window.ctxgZ.stroke();
		
		window.ctxgX.strokeStyle = "#F5DA81";		
		window.ctxgX.font = "30px Arial";
		window.ctxgX.strokeText("X", (GRAFICA_AMPLE-20), (GRAFICA_ALT-4));
		window.ctxgX.stroke();
		window.ctxgY.strokeStyle = "#F5DA81";
		window.ctxgY.font = "30px Arial";
		window.ctxgY.strokeText("Y", (GRAFICA_AMPLE-20), (GRAFICA_ALT-4));
		window.ctxgY.stroke();
		window.ctxgZ.strokeStyle = "#F5DA81";
		window.ctxgZ.font = "30px Arial";
		window.ctxgZ.strokeText("Z", (GRAFICA_AMPLE-20), (GRAFICA_ALT-4));
		window.ctxgZ.stroke();

		window.ctxgX.strokeStyle = "#F3E2A9";
		window.ctxgX.moveTo(0,(GRAFICA_ALT/2));
		window.ctxgX.lineTo(GRAFICA_AMPLE,(GRAFICA_ALT/2));
		window.ctxgX.stroke();
		
		window.ctxgY.strokeStyle = "#F3E2A9";
		window.ctxgY.moveTo(0,(GRAFICA_ALT/2));
		window.ctxgY.lineTo(GRAFICA_AMPLE,(GRAFICA_ALT/2));
		window.ctxgY.stroke();
		
		window.ctxgZ.strokeStyle = "#F3E2A9";
		window.ctxgZ.moveTo(0,(GRAFICA_ALT/2));
		window.ctxgZ.lineTo(GRAFICA_AMPLE,(GRAFICA_ALT/2));
		window.ctxgZ.stroke();
		
		window.ndxMostra = 0;
		
	}
	
	/**
	 * Esborra les grafiques i les deixa en blanc per a noves visualitzacions
	 */
	this.esborraBaseGrafica = function() {
		document.getElementById("g1").innerHTML = "";
		document.getElementById("g2").innerHTML = "";
		document.getElementById("g2").innerHTML = "";
	}
	

	/**
	 * Metode que elimina les mostres obtingudes i inicialitza per a una nova captura
	 */	
	this.eliminarMostreig = function() {
		window.gAccelerometre.esborraBaseGrafica();
		window.gAccelerometre.dibuixaBaseGrafica();
		llmostres.esborraLlista();
	}

	/**
	 * Proces de mostreig de les dades de l'accelerometre
	 */
	this.iniciarMostreig = function() {
		
		llmostres.esborraLlista();
		this.idEventMostreig = navigator.accelerometer.watchAcceleration(
    			
    			function(acceleracio) {
    				
    				if(gAccelerometre.getAccelerometre().getEstat()==ESTAT_INDETERMINAT) {
    					gAccelerometre.getAccelerometre().setEstat(ESTAT_CORRECTE);	// Iniciat correctament
    					var accHtml = document.getElementById('accelerometre_cap');
    					accHtml.src = "./img/icona_correcte.png";
    				}
    				
    		    	// Calculem els increments
    				var incT;
    				var incX;
    		    	var incY;
    		    	var incZ;

    				if(gAccelerometre.prevT==0) {
    					incX = 0;
    					incY = 0;
    					incZ = 0;
    					incT = 0;
    					gAccelerometre.prevT = acceleracio.timestamp;
    				}else{
        				incX = acceleracio.x - gAccelerometre.prevX;
        		    	incY = acceleracio.y - gAccelerometre.prevY;
        		    	incZ = acceleracio.z - gAccelerometre.prevZ;
        				incT = acceleracio.timestamp - gAccelerometre.prevT;
    				}
    		    	
    		    	gAccelerometre.prevX = acceleracio.x;
    		    	gAccelerometre.prevY = acceleracio.y;
    		    	gAccelerometre.prevZ = acceleracio.z;
    		    	gAccelerometre.prevT = acceleracio.timestamp;

    		    	
	    		    	// Captura una mostra de l'estat de l'accelerometre i la incorpora a la llista de mostres
	    		    	nouAcc = new Accelerometre();
	    		    	nouAcc.setCoordX(incX);
	    		    	nouAcc.setCoordY(incY);
	    		    	nouAcc.setCoordZ(incZ);
	    		    	nouAcc.setTStamp(incT);
	    		    	
	    		    	var consis = document.getElementById('accelerometre_cap');
	    		    	consis.innerHTML = 	'Mostres: ' + llmostres.obtenirNombreElements();

  		    			// Dibuixa la mostra a la grafica
   						var aX = (GRAFICA_ALT/2)-Math.floor(incX*GRAFICA_ALT_ZOOM);
   						var aY = (GRAFICA_ALT/2)-Math.floor(incY*GRAFICA_ALT_ZOOM);
   						var aZ = (GRAFICA_ALT/2)-Math.floor(incZ*GRAFICA_ALT_ZOOM);

   						if(window.ndxMostra==0 || (GRAFICA_AMP_ZOOM*window.ndxMostra) >= GRAFICA_AMPLE) {

   							window.gAccelerometre.esborraBaseGrafica();
   							window.gAccelerometre.dibuixaBaseGrafica();

   							window.ctxgX.moveTo(0, aX);
   							window.ctxgY.moveTo(0, aY);
   							window.ctxgZ.moveTo(0, aZ);
							window.ndxMostra = 0;
   						}

   						window.ndxMostra+=incT;
						aT = GRAFICA_AMP_ZOOM*(Math.floor(window.ndxMostra));
   	   		    		// Llindar per eliminar soroll de fons
   	   		    		if(aX<=MOSTREIG_FILTRE){aX=0}
   	   		    		if(aY<=MOSTREIG_FILTRE){aY=0}
   	   		    		if(aZ<=MOSTREIG_FILTRE){aZ=0}
						
   	   		    		// Dibuixar la linia de grafica
						window.ctxgX.strokeStyle = "blue";
						window.ctxgX.lineWidth = 0.25;
						window.ctxgX.lineTo(aT, aX);
   						window.ctxgX.stroke();
						
						window.ctxgY.strokeStyle = "blue";
						window.ctxgY.lineWidth = 0.25;
						window.ctxgY.lineTo(aT, aY);
   						window.ctxgY.stroke();						
						
						window.ctxgZ.strokeStyle = "blue";
						window.ctxgZ.lineWidth = 0.25;
   						window.ctxgZ.lineTo(aT, aZ);
   						window.ctxgZ.stroke();
  						
   						/* Fi grafica */ 

   		   		    	
   	   		    		// Llindar per eliminar soroll de fons per desar el moviment
   	   		    		if(Math.abs(incX) > MOSTREIG_FILTRE || 
   	   		    				Math.abs(incY) > MOSTREIG_FILTRE ||
   	   		    				Math.abs(incZ) > MOSTREIG_FILTRE) {
   	   		    			
   	   		    			llmostres.afegirMostra(nouAcc);
   	   	    		    	gAccelerometre.ultimTimestampCapturat=acceleracio.timestamp;
   	   		    		}
    		    	
    		    }
    			
    			, 
    			
    			function(errAcc) {
    				gAccelerometre.getAccelerometre().setEstat(ESTAT_ERROR);	// No iniciat o amb error
    		    	var accHtml = document.getElementById('accelerometre_cap');
    		    	accHtml.src = "./img/icona_incorrecte.png";
    		    }
    			
    			, 
    			
        		{ frequency: 1000/FREQUENCIA_MOSTREIG });
    };
    
	/**
	 * Peticio per aturar el mostreig de les dades de l'accelerometre
	 */
    this.confirmarAturarMostreig=function() {
        navigator.notification.confirm(
           'Enviar Mostres?',
           this.confirmarEnviar,
           'Mostreig aturat.',
           'No,Si'
        );
    }
    this.confirmarEnviar=function(buttonIndex) {
    	if (buttonIndex==2){
    		gAccelerometre.aturarMostreig();
        }
    }

	/**
	 * Aturar el mostreig de les dades de l'accelerometre
	 */
    this.aturarMostreig = function() {
    	if (this.idEventMostreig) {
            navigator.accelerometer.clearWatch(gAccelerometre.idEventMostreig);
            delete gAccelerometre.idEventMostreig;
            navigator.accelerometer.clearWatch(gAccelerometre.idEventProcesMostreig);
            delete gAccelerometre.idEventProcesMostreig;
            var accHtml = document.getElementById('accelerometre_cap');
	    	accHtml.src = "./img/icona_incorrecte.png";
        }
        if (this.idEventProcesMostreig) {
            navigator.accelerometer.clearWatch(gAccelerometre.idEventProcesMostreig);
            delete gAccelerometre.idEventProcesMostreig;
            var accHtml = document.getElementById('accelerometre_sam');
	    	accHtml.src = "./img/icona_incorrecte.png";
        }

		// Si s'ha detectat acceleracions aleshores s'envia un moviment de sisme al servidor
    	// Nomes es genera el moviment si la captura no es un fals positiu (menys de n mostres)
        if(llmostres.obtenirNombreElements() >= MOSTRES_FALS_POSITIU) {
        	lltemp = llmostres;
			var movint = gAccelerometre.calculaMagnitud(lltemp);

			// Nomes es genera el moviment si la intensitat calculada es igual o superior a la preestablerta a la configuracio
			if(movint >= INTENSITAT_MAX_FALS_POSITIU) {
				window.gSisme.crearSisme(true, window.gGeolocalitzador.getLocalitzacioActual().getLatitud(),
						window.gGeolocalitzador.getLocalitzacioActual().getLongitud(), movint, lltemp);
			}
			window.gGeolocalitzador.eliminarMostreig();
			window.gGeolocalitzador.esborraBaseGrafica();
			
		}
    
    };

    
	/**
	 * Test de l'accelerometre
	 */
	this.testAccelerometre = function() {
    	this.idEventAccelerometre = navigator.accelerometer.watchAcceleration(
    			
    			function(acceleracio) {

    				window.gAccelerometre.getAccelerometre().setEstat(ESTAT_CORRECTE);	// Iniciat correctament
    		    	var accHtml = document.getElementById('accelerometre_sts');
    		    	accHtml.src = "./img/icona_correcte.png";

    		    	window.gAccelerometre.getAccelerometre().setCoordX(acceleracio.x);
    		    	window.gAccelerometre.getAccelerometre().setCoordY(acceleracio.y);
    		    	window.gAccelerometre.getAccelerometre().setCoordZ(acceleracio.z);
    		    	var consis = document.getElementById('accelerometre_sis');
    		    	consis.innerHTML = 	'X: ' + window.gAccelerometre.getAccelerometre().getCoordX() + '<br />' +
    		    						'Y: ' + window.gAccelerometre.getAccelerometre().getCoordY() + '<br />' +
    		    						'Z: ' + window.gAccelerometre.getAccelerometre().getCoordZ() + '<br />' +
    		    						'T: ' + acceleracio.timestamp + '<br />';
    	            navigator.accelerometer.clearWatch(this.idEventAccelerometre);
    	            window.gAccelerometre.idEventAccelerometre = 0;
    		    }
    			
    			, 
    			
    			function(errAcc) {
    				window.accelerometre.setEstat(ESTAT_ERROR);	// No iniciat o amb error
    		    	var accHtml = document.getElementById('accelerometre_sts');
    		    	accHtml.src = "./img/icona_incorrecte.png";
    	            navigator.accelerometer.clearWatch(window.gAccelerometre.idEventAccelerometre);
    	            window.gAccelerometre.idEventAccelerometre = 0;
    		    }
    			
    			, 
    			
        		{ frequency: TEST_MS_ACCELEROMETRE });
    	
	};



	/**
	 * Calcula la intensitat del terratremol i l'assigna a una magnitud per poder ser usada
	 */
    this.calculaMagnitud = function(lls) {

    	var llsElem = lls.obtenirNombreElements();
    	mostraMax = lls.obtenirMostra(0);
    	valorMax = mostraMax.getCoordX();

    	// Obtenir la mostra amb valor mes gran (amplitud mes gran)
    	for(var r=0; r< llsElem; r++) {
    		accsam = lls.obtenirMostra(r);
    		if(accsam.getCoordX() > valorMax) {
        		valorMax = accsam.getCoordX();
    			mostraMax = accsam;
    		}
    		if(accsam.getCoordY() > valorMax) {
        		valorMax = accsam.getCoordY();
    			mostraMax = accsam;
    		}
    		// De moment nomes es valoren les ones P (x,y) i les S es deixen de banda ja que hi ha un problema
    		// que encara no s'ha pogut trobar
//    		if(accsam.getCoordZ() > valorMax) {
//        		valorMax = accsam.getCoordZ();
//        		mostraMax = accsam;
//    		}
    	}
// Per implementar en el futur: Mostrar el nivell de l'escala MM i la descripcio a l'aplicacio del mobil
// com a alerta.
//    	valret = this.escalaMercalli.obtenirIntensitatMercalli(valorMax);
    	
    	// Calculem la resultant de les acceleracions x y
    	x = mostraMax.getCoordX();
    	y = mostraMax.getCoordY();
    	resultant = Math.sqrt(Math.pow(x, 2) + Math.pow(y, 2));
    	
 		return resultant;
 	};
 	
 	
	/**
	 * Getters
	 */ 	
 	this.getMagnitud = function() {
 		return this.magnitud;
 	}
 	
 	this.getAccelerometre = function() {
 		return this.accelerometre;
 	}
 	
 	this.getLlmostres = function() {
 		return llmostres;
 	}
 	
 	this.getLlmostresTest = function() {
 		return llmostresTest;
 	}
 	
 	
}


/**
 * Classe Magnitud
 */
function Magnitud() {
	
	// Atributs
	
 	this.intensitat = 0.0;

 	// Metodes getters i setters
 	this.getIntensitat = function() {
 		return this.intensitat;
 	};
 	
 	this.setIntensitat = function(intensitat) {
 		this.intensitat = intensitat;
 	};
 	
}


/**
 * Classe Mercalli (S'hauria d'implementar externament al codi)
 */
function Mercalli() {
	
	// Atributs
	
 	this.intensitatMercalli = 1;	// Escala mes baixa de Mercalli
 	this.acceleracioSismicaMinima = -9999;	// Acceleracio sismica minima equivalent a escala Mercalli 1 (%g)
 	this.acceleracioSismicaMaxima = 0.0017;	// Acceleracio sismica maxima equivalent a escala Mercalli 1 (%g)
 	this.velocitatSismicaMinima = -9999;	// Acceleracio sismica minima equivalent a escala Mercalli 1 (cm/s)
 	this.velocitatSismicaMaxima = 0.1;	// Acceleracio sismica maxima equivalent a escala Mercalli 1 (cm/s)
 	this.percepcioSisme = 'No apreciable';	// Descripcio de la percepcio del sisme escala Mercalli 1

 	// Getters Mercalli
 	this.getIntensitatMercalli = function() {
 		return this.intensitatMercalli;
 	};
 	this.getAcceleracioSismicaMinima = function() {
 		return this.acceleracioSismicaMinima;
 	};
 	this.getAcceleracioSismicaMaxima = function() {
 		return this.acceleracioSismicaMaxima;
 	};
 	this.getVelocitatSismicaMinima = function() {
 		return this.velocitatSismicaMinima;
 	};
 	this.getVelocitatSismicaMaxima = function() {
 		return this.velocitatSismicaMaxima;
 	};
 	this.getPercepcioSisme = function() {
 		return this.percepcioSisme;
 	};
 	
 	this.crearIntensitat = function(parm1, parm2, parm3, parm4, parm5, parm6) {
 		this.intensitatMercalli = parm1;
 		this.acceleracioSismicaMinima = parm2;
 		this.acceleracioSismicaMaxima = parm3;
 		this.velocitatSismicaMinima = parm4;
 		this.velocitatSismicaMinima = parm5;
 		this.percepcioSisme = parm6;
 	};
 	

 	/**
 	 * Metode generic per obtenir la intensitat escala Mercalli a partir de l'acceleracio maxima
 	 * 
 	 */
 	this.carregaTaulaMercalli = function() {
		
 		mrc1 = new Mercalli();
		mrc1.crearIntensitat(1, -999, 0.005, -999, 0.1, 'MOLT DEBIL');
		llmercalli.push(mrc1);
	
		mrc2 = new Mercalli();
		mrc2.crearIntensitat(2, 0.005, 0.025, 0.1, 1.1, 'DEBIL');
		llmercalli.push(mrc2);

		mrc3 = new Mercalli();
		mrc3.crearIntensitat(3, 0.025, 0.06, 1.1, 3.4, 'LLEU');
		llmercalli.push(mrc3);

		mrc4 = new Mercalli();
		mrc4.crearIntensitat(4, 0.06, 0.1, 3.4, 8.1, 'MODERAT');
		llmercalli.push(mrc4);

		mrc5 = new Mercalli();
		mrc5.crearIntensitat(5, 0.1, 0.2, 8.1, 16, 'POC FORT');
		llmercalli.push(mrc5);

		mrc6 = new Mercalli();
		mrc6.crearIntensitat(6, 0.2, 0.35, 16, 31, 'FORT');
		llmercalli.push(mrc6);

		mrc7 = new Mercalli();
		mrc7.crearIntensitat(7, 0.35, 0.6, 31, 60, 'MOLT FORT');
		llmercalli.push(mrc7);

		mrc8 = new Mercalli();
		mrc8.crearIntensitat(8, 0.6, 1, 60, 116, 'DESTRUCTIU');
		llmercalli.push(mrc8);

		mrc9 = new Mercalli();
		mrc9.crearIntensitat(9, 1, 2.5, 116, 999, 'RUINOS');
		llmercalli.push(mrc9);

		mrc10 = new Mercalli();
		mrc10.crearIntensitat(10, 2.5, 5, 116, 999, 'DESASTROS');
		llmercalli.push(mrc10);

		mrc11 = new Mercalli();
		mrc11.crearIntensitat(11, 5, 999, 116, 999, 'CATASTROFIC');
		llmercalli.push(mrc11);

 	};
 	
 	/**
 	 * Metode per obtenir la intensitat a partir del %g acceleracio maxima detectada
 	 */
 	this.obtenirIntensitatMercalli = function(acceleracioDetectada) {
 		// Retorna la intensitat en escala Mercalli o 0 si no la ha trobat
		var intmer = 0
		for (var n=0; n < 1; n++) {
			if( acceleracioDetectada >= llmercalli[n].getAcceleracioSismicaMinima() 
					&& acceleracioDetectada < llmercalli[n].getAcceleracioSismicaMaxima() ) {
				intmer = llmercalli[n].getIntensitatMercalli();
				break;
			}
		}
		return intmer;
	};
	
}