/**
 *  SISTEMA DE DETECCIO DE MOVIMENTS SISMICS PER A DISPOSITIUS MOBILS                                                                                      *
 *  Treball final de Master en Programari Lliure (UOC) 
 *  (C) Copyright 2014 Jaime Anton Lopez Diaz (jlopezdia@uoc.edu)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

/*---------------------------------------------------------------------------------------- 
 * Classe MovimentSismic: defineix un moviment sismic
 * 
 *----------------------------------------------------------------------------------------*/
function Sisme(st, lat, long, magn, dh, mt) {

	// Atributs
	this.latitud = lat;
	this.longitud = long; 
	this.magnitud = magn;
	this.datahora = dh;
	this.llcaptures = mt;
	this.estat = st;

	
	// Metodes

   
	// Getter
	this.getEstat = function() {
		return this.estat;
	};
	
	
	// Getter
	this.getLatitud = function() {
		return this.latitud;
	};
	
	// Getter
	this.getLongitud = function() {
		return this.longitud;
	};
	
	// Getter
	this.getMagnitud = function() {
		return this.magnitud;
	};
	
	// Getter
	this.getDatahora = function() {
		return this.datahora;
	}; 
	
	// Getter
	this.getLlcaptures = function() {
		return this.llcaptures;
	}; 
	
	// Setter
	this.setEstat = function(st) {
		this.estat = st;
	};
	
	// Setter
	this.setLatitud = function(l) {
		this.latitud = l;
	};
	
	// Setter
	this.setLongitud = function(l) {
		this.longitud = l;
	};
	
	
	// Setter
	this.setMagnitud = function(mag) {
		this.magnitud = mag;
	};

	// Setter
	this.setDatahora = function(dh) {
		this.datahora = dh;
	}; 

	// Setter
	this.setLlcaptures = function(mt) {
		this.captures = mt;
	}; 
}


/*---------------------------------------------------------------------------------------- 
 * Classe LlistaSismes: Gestiona una llista de moviments sismics
 *----------------------------------------------------------------------------------------*/
function LlistaSismes() {
	// Atributs
	var llsismes = new Array();

	
	// Metodes:
	
	// Afegir moviment sismic a la llista
	this.afegirSisme = function(sisme) {
    	llsismes.push(sisme);
	};
	
	// Eliminar moviment sismic de la llista
	this.eliminarSisme = function(index) {
		llsismes.splice(index, 1);
	};
	
	// Obtenir el nombre d'elements de la llista
	this.obtenirNombreElements = function() {
		return llsismes.length;
	};
	
	// Afegir moviment sismic al principi de la llista
	this.afegirSismeInici = function(sisme) {
		llsismes.unshift(sisme);
	};
	
	// Modifica un element de la llista
	this.modificarSisme = function(index, sisme) {
		llsismes[index] = sisme;
	};
	
	// Recupera un element de la llista
	this.obtenirSisme = function(index) {
		return llsismes[index];
	};
	
	// Retorna l'index d'un element de la llista a partir de Datahora (timestamp, únic)
	// -1 = No l'ha trobat
	this.obtenirSismeDth = function(sisme) {
		var index = -1;
		for (var n=0; n < this.obtenirNombreElements(); n++) {
			if( this.obtenirSisme(n).getDatahora() == sisme.getDatahora() ) {
				index = n;
				break;
			}
		}
		return index;
	};
	
	
		// Genera la taula de moviments pendents a partir de la llista de moviments sismics llmvsms
		this.generaTaulaHtml = function() {

			var _innerHtml = "<table id=\"tabmov\" class=\"table1\">" +
					"<thead>" +
					"<tr id=\"headfilamov\">" +
						"<th scope=\"col\" abbr=\"Sts\">Sts</th>" +
						"<th scope=\"col\" abbr=\"Data\">Data</th>" +
						"<th scope=\"col\" abbr=\"Lat\">Lat</th>" +
						"<th scope=\"col\" abbr=\"Long\">Long</th>" +
						"<th scope=\"col\" abbr=\"Int\">Int</th>" +
					"</tr>" +
					"</thead>" +
					"<tbody id=\"tbodymov\">";
			
			for (var n=0; n < this.obtenirNombreElements(); n++) {
				_innerHtml += "<tr>";
				_innerHtml += "<td>"+this.obtenirSisme(n).getEstat()+"</td>";
				_innerHtml += "<td>"+this.timestampToDatetime(this.obtenirSisme(n).getDatahora())+"</td>";
				_innerHtml += "<td>"+this.obtenirSisme(n).getLatitud()+"</td>";
				_innerHtml += "<td>"+this.obtenirSisme(n).getLongitud()+"</td>";
				_innerHtml += "<td>"+this.obtenirSisme(n).getMagnitud()+"</td>";
				_innerHtml += "</tr>";
			}
			
			_innerHtml += "</tbody></table>"
			document.getElementById("tablemoviments").innerHTML = _innerHtml;
		};

     	
        // Auxiliar per convertir la data i hora de la taula
   	    this.timestampToDatetime = function(tmstmp) {
   	    	var dts = new Date(tmstmp);
   	    	var any = dts.getFullYear();
   	    	var mes = dts.getMonth()+1;
   	    	var dia = dts.getDate();
   	    	var hora = dts.getHours();
   	    	var minuts = dts.getMinutes();
   	    	var segons = dts.getSeconds();
   	    	var datahoratxt = dia+"-"+mes+"-"+any+"\n"+hora+":"+minuts+":"+segons;
   	    	return datahoratxt;
   	    };


}




/*---------------------------------------------------------------------------------------- 
 * Classe GestorMovimentsSismics: Gestiona els moviments sismics
 *----------------------------------------------------------------------------------------*/
function GestorSisme() {

	// Atributs
	window.llsismes = new LlistaSismes();
 	var enviament = new Enviament();
	enviament.servidor.setEstat(ESTAT_INDETERMINAT);
 	enviament.setEstat(ESTAT_INDETERMINAT);

	
	/* Metode que genera un nou moviment i el posa a la llista d'enviaments
	 * Tipus de moviment: P=Pendent d'enviar, T=Moviment de test, R=Moviment no enviat que es torna a 
	 * posar a la cua per reintentar l'enviament, C=Enviament en curs
	 */
	this.crearSisme = function(tipus, latitud, longitud, magnitud, mostra) {
	
		var dh=new Date();			// Data i Hora actuals
		var dhms = dh.getTime();	// Data actual en milisegons
	
		if(tipus==true) {
			// Moviment real
			sisme = new Sisme(ENV_TIPUS_PENDENT, latitud, longitud, magnitud, dhms, mostra);
			window.llsismes.afegirSisme(sisme);
			delete sisme;
			window.llsismes.generaTaulaHtml();	// Redibuixa la taula a la pagina html
		
			// Activa els enviaments automatics si no estan activats
			if(enviament.getEstat() == ESTAT_INDETERMINAT) {
				this.activarEnviamentAutomatic();
			}
		}else{
			// Moviment de test
			var stest = new Sisme(ENV_TIPUS_TEST, GL_DEF_LATITUD, GL_DEF_LONGITUD, MAG_DEF, dhms, window.gAccelerometre.getLlmostresTest());
			this.enviarSisme(stest);
		}
	};
	
	
	
	/*---------------------------------------------------------------------------------------- 
	 * Timer per enviament automatic d'un moviment cada 15 segons
	 * 
	 * S'ha de començar a executar nomes quan el sistema estigui tot ok
	 * 
	 *----------------------------------------------------------------------------------------*/
	// Metode que activa el timer d'enviaments automatics
	this.activarEnviamentAutomatic = function() {
		var eId = window.setInterval(function() {
		
			// Envia el primer element de la llista, nomes si hi ha elements a la llista
			if(window.llsismes.obtenirNombreElements()>0) {
				// Hauria de ser "enviar primer moviment que no s'estigui enviant ja"
				sisme = window.llsismes.obtenirSisme(0);
				sisme.setEstat(ENV_TIPUS_EN_CURS);		// Canvia l'estat a "moviment enviant-se"
				window.llsismes.generaTaulaHtml();	// Redibuixa la taula a la pagina html
	    		var nxc=sisme.getLlcaptures().obtenirNombreElements();
				window.gSisme.enviarSisme(sisme);
			}else{
				// Si no hi ha moviments pendents a la llista, desactivem enviament automatic per estalviar recursos
				window.gSisme.desactivarEnviamentAutomatic();
			}
			
		
		}, enviament.getInterval());
		enviament.setId(eId);
		enviament.setEstat(ESTAT_CORRECTE);
	};

	// Metode que desactiva el timer d'enviaments automatics
	this.desactivarEnviamentAutomatic = function() {
		window.clearInterval(enviament.getId());
		enviament.setEstat(ESTAT_INDETERMINAT);
	};
	
	

	/**
	 * Mostra l'estat del servidor remot en el test o pantalla de configuracio
	 */
	this.mostrarEstatServidorRemot = function()
    {
    	var consts = document.getElementById('hiHaAccesServidor_sts');
    	var consis = document.getElementById('hiHaAccesServidor_sis');
    	
    	this.crearSisme(false);	// Enviem un moviment de test per verificar que el servidor funcioni
  	    switch(enviament.getServidor().getEstat())
  	    {
  	    case ESTAT_INDETERMINAT:
    		consts.src = "./img/icona_en_curs.gif";
		    break;
  	    case ESTAT_CORRECTE:
    		consts.src = "./img/icona_correcte.png";
    		consis.innerHTML = "DISPONIBLE";
  	    	break;
  	    case ESTAT_ERROR:
    		consts.src = "./img/icona_incorrecte.png";
    		consis.innerHTML = "NO DISPONIBLE";
  	    	break;
  	    }
    };

	/**
	 * Mostra l'estat dels enviaments automatics a la pantalla de configuracio
	 */    
    this.mostrarEstatEnviamentAutomatic = function()
    {
    	var consis = document.getElementById('ind_env_auto_activat_sis');
    	if(enviament.getEstat()==ESTAT_CORRECTE) {
    		consis.innerHTML = "ACTIVATS";
    	}else{
    		consis.innerHTML = "DESACTIVATS";
    	}
    };

    /*
     * ENVIAMENT MOVIMENT SISMIC
     * 
     * el parametre test indica:
     *    TRUE: l'enviament es per fer una prova de connectivitat amb el servidor. No s'envien dades
     *    FALSE: es tracta d'un enviament de dades
     *    
     *    
     */
    this.enviarSisme = function(sisme) {
    	
			var wsurl = enviament.getServidor().getUrl();
    		var wsnom = enviament.getServidor().getWsNom();
    		var wsns = enviament.getServidor().getNs();
    		
    		// Preparacio del missatge SOAP
    		var strllcsoapX = "";	// Preparar la cadena per al parametre 4 (llista mostres) del missatge de SOAP
    		var strllcsoapY = "";	// Preparar la cadena per al parametre 5 (llista mostres) del missatge de SOAP
    		var strllcsoapZ = "";	// Preparar la cadena per al parametre 6 (llista mostres) del missatge de SOAP
    		var strllcsoapT = "";	// Preparar la cadena per al parametre 7 (llista mostres) del missatge de SOAP

    		var nxc=sisme.getLlcaptures().obtenirNombreElements();
    		for( var t=0; t < nxc; t++ ){
    			strllcsoapX+="<arg4>"+sisme.getLlcaptures().obtenirMostra(t).getCoordX()+"</arg4>";
    		}
    		for( var t=0; t < nxc; t++ ){
    			strllcsoapY+="<arg5>"+sisme.getLlcaptures().obtenirMostra(t).getCoordY()+"</arg5>";
    		}
    		for( var t=0; t < nxc; t++ ){
    			strllcsoapZ+="<arg6>"+sisme.getLlcaptures().obtenirMostra(t).getCoordZ()+"</arg6>";
    		}
    		for( var t=0; t < nxc; t++ ){
    			strllcsoapT+="<arg7>"+sisme.getLlcaptures().obtenirMostra(t).getTStamp()+"</arg7>";
    		}
    		
        	var xmlhttp = new XMLHttpRequest();

            xmlhttp.open('POST', wsurl, true);

            var msgSoap =
                '<?xml version=\"1.0\" encoding=\"utf-8\"?>' +
                '<s11:Envelope xmlns:s11=\"http://schemas.xmlsoap.org/soap/envelope/\">' +
                '<s11:Body>' +
                  '<ns1:rcvData xmlns:ns1=\"'+wsns+'\">' +
                    '<arg0>'+sisme.getLatitud()+'</arg0>' +
                    '<arg1>'+sisme.getLongitud()+'</arg1>' +
                    '<arg2>'+sisme.getMagnitud()+'</arg2>' +
                    '<arg3>'+sisme.getDatahora()+'</arg3>' + 
                    strllcsoapX + strllcsoapY + strllcsoapZ + strllcsoapT +
                  '</ns1:rcvData>' +
                '</s11:Body>' +
              '</s11:Envelope>';
                		
            // Prepara l'actualitzacio dels indicadors a les pantalles
        	var consts = document.getElementById('hiHaAccesServidor_sts');
        	var consis = document.getElementById('hiHaAccesServidor_sis');
            
        	// Enviament del missatge SOAP
            xmlhttp.onreadystatechange = function () {
                if (xmlhttp.readyState == 4) {
                    if (xmlhttp.status == 200) {

        				rawdata = xmlhttp.responseXML;
        				var resultNode = rawdata.documentElement.getElementsByTagName("rcvDataResponse");
        				var resultValue = resultNode.toString();
        				rcvData_handler(resultValue);   // Processar el valor retornat pel servidor
        				
        				// PROCES ENVIAMENT: Dona com a ben enviat el moviment i l'esborra de la llista
        				if(sisme.getEstat()!=ENV_TIPUS_TEST) {		// Nomes si no es moviment de Test
            				var resmov = window.llsismes.obtenirSismeDth(sisme);
            				if( resmov > -1 ) {  // Ha trobat el moviment a la llista
            					window.llsismes.eliminarSisme(resmov);	// Elimina el moviment de la llista
            					window.llsismes.generaTaulaHtml();	// Redibuixa la taula a la pagina html            				}
            				}
            			}else{
            		    	// TEST INICIAL: mostra icona o info a la pagina html i assigna codi d'estat
            				enviament.getServidor().setEstat(ESTAT_CORRECTE);
            				consts.src = "./img/icona_correcte.png";
            	    		consis.innerHTML = "DISPONIBLE";
        				}
        				
        			}else{
        				// ERROR PROCES ENVIAMENT: Canvia el tipus del moviment i el posa al final de la llista
        				if(sisme.getEstat()!=ENV_TIPUS_TEST) {		// Nomes si no es moviment de Test
        					var resmov = window.llsismes.obtenirSismeDth(sisme);
        					if( resmov > -1 ) {  // Ha trobat el moviment a la llista
        						window.llsismes.eliminarSisme(resmov);	// Elimina el moviment de la llista per evitar duplicitat
        						sisme.setEstat(ENV_TIPUS_REENVIAR);
        						window.llsismes.afegirSisme(sisme);
        						window.llsismes.generaTaulaHtml();	// Redibuixa la taula a la pagina html
        					}
        				}else{
        					// ERROR TEST INICIAL: mostra icona o info a la pagina html i assigna codi d'estat
        					enviament.getServidor().setEstat(ESTAT_ERROR);
        					consts.src = "./img/icona_incorrecte.png";
        					consis.innerHTML = "NO DISPONIBLE";
        				}
        			}
                }
            }
            // Envia la peticio POST
            xmlhttp.setRequestHeader("Content-Type","text/xml; charset=utf-8");
            xmlhttp.setRequestHeader( "SOAPAction", wsnom );
            xmlhttp.send(msgSoap);
        };
        
        
    	// Funcio per si volem controlar les respostes del servidor. En principi, es pot fer, però no es 
        // imprescindible i no es fa per aprofitar recursos
    	function rcvData_handler(/*long*/ resultValue) {};
    	

    	/**
    	 * Getters i setters
    	 */
     	// Retorna la llista
     	this.getLlsismes = function() {
     		return window.llsismes;
     	};
     	
   	
     	// Retorna un enviament
     	this.getEnviament = function() {
     		return enviament;
     	};
   		
}

